.. include:: ../README.rst

Documentation
-------------

.. toctree::
   :hidden:
   :maxdepth: 2

   concepts
   api/index
   history
   contributing



Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
